Module slice_pool2::unsync
source · Expand description
Unsynchronized memory pools.
Structs
- An allocation in an owned
SlicePool. - A non thread-safe interface for allocating chunks in an owned slice.
Traits
- Interface for any slice compatible with a non thread-safe
SlicePool.